"use strict";
/*
 * Copyright 2020 Adobe. All rights reserved.
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
 * OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMediaQuery = void 0;
const react_1 = require("react");
const ssr_1 = require("@react-aria/ssr");
function useMediaQuery(query) {
    const supportsMatchMedia = typeof window !== 'undefined' && typeof window.matchMedia === 'function';
    const [matches, setMatches] = (0, react_1.useState)(() => supportsMatchMedia ? window.matchMedia(query).matches : false);
    (0, react_1.useEffect)(() => {
        if (!supportsMatchMedia) {
            return;
        }
        const mq = window.matchMedia(query);
        const onChange = (evt) => {
            setMatches(evt.matches);
        };
        mq.addListener(onChange);
        return () => {
            mq.removeListener(onChange);
        };
    }, [supportsMatchMedia, query]);
    // If in SSR, the media query should never match. Once the page hydrates,
    // this will update and the real value will be returned.
    const isSSR = (0, ssr_1.useIsSSR)();
    return isSSR ? false : matches;
}
exports.useMediaQuery = useMediaQuery;
//# sourceMappingURL=use-media-query.js.map